/*
 * FILE:
 * filter.c
 *
 * FUNCTION: 
 * Provide a set of data filters that turn strings of one 
 * type into strings of another.
 *
 * HISTORY:
 * Linas Vepstas March 2002
 */

#include <string.h>

#include "filter.h"
#include "perr.h"

/* =================================================================== */

static const char * 
is_null (const char * val)
{
	if (!val) return "null";
	return NULL;
}

/* =================================================================== */

static const char * 
is_whitespace_or_null (const char * val)
{
	val = whitespace_filter (val);
	if (!val) return "null";
	return NULL;
}

/* =================================================================== */
/* return NULL if the field is whitespace (blank, tab, formfeed etc.)  */

const char *
whitespace_filter (const char * val)
{
	size_t len;
	if (!val) return NULL;

	len = strspn (val, "\a\b\t\n\v\f\r ");
	if (0 == val[len]) return NULL;
	return val+len;
}

/* =================================================================== */

DuiFilter 
dui_filter_find_by_name (const char *filtername)
{
	if (!filtername) return NULL;

	if (!strcmp ("is_null", filtername))
	{
		return is_null;
	}

	if (!strcmp ("is_whitespace_or_null", filtername))
	{
		return is_whitespace_or_null;
	}

	if (!strcmp ("whitespace", filtername))
	{
		return whitespace_filter;
	}

   SYNTAX ("unknown filter \"%s\"", filtername);
	return NULL;
}

/* =========================== END OF FILE ======================= */

